@@ -3,13 +3,14 @@
 #'
 #' @description
 #' Map an object \code{x} into equal (or nearly equal) size folds.
+#' If \code{x} is a positive integer, a vector of FoldIDs of length matching x is returned, otherwise
 #' If \code{x} is a vector, a matching vector of FoldIDs is returned.
 #' If \code{x} is a data.table, a list of partitions of x is returned.
 #'
 #' @details
 #' Convenient method for mapping an object into equal size folds, potentially with stratification
 #'
-#' @param x A vector of values or a data.table object
+#' @param x A positive integer, a vector of values or a data.table object
 #' @param stratified If x is a vector then TRUE or FALSE indicating whether x's split the class's of x proportionally. If x
 #' is a data.table then \code{stratified} should be FALSE or the name of a column in x on which to perform stratification. Note
 #' that stratification is implemented for categorical, logical, AND numeric x
@@ -18,6 +19,7 @@
 #'
 #' @examples
 #' library(data.table)
+#' folds(8, nfolds=2)
 #' folds(alien.train$IsAlien, nfolds=2)
 #' folds(alien.train$IsAlien, nfolds=2, stratified=TRUE, seed=2016)
 #' folds(alien.train$IQScore, nfolds=2, stratified=TRUE, seed=2016)
@@ -52,7 +54,14 @@ folds <- function(x, nfolds=5L, stratified=FALSE, seed=NULL){
   }
   
   #--------------------------------------------------
-  # If x is a vector
+  # If x is a vector of length 1 and is a positive integer
+  
+  if(length(x) == 1 & x[1] > 1 & x[1] %% 1 == 0){
+    return(folds(rep(x = 1L, x), nfolds = nfolds, stratified = FALSE, seed = seed))
+  }
+  
+  #--------------------------------------------------
+  # If x is a vector, length > 1
   
   set.seed(seed)
   if(stratified){
